#
# spec file for package lxqt-notificationd
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lxqt-notificationd
Version:        2.2.0
Release:        1.1
Summary:        LXQt Notification daemon
License:        LGPL-2.1-or-later
URL:            https://github.com/lxqt/lxqt-notificationd
Source:         %{url}/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  cmake >= 3.5.0
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF6WindowSystem)
BuildRequires:  cmake(LayerShellQt) >= 6.0.0
BuildRequires:  cmake(Qt6DBus)
BuildRequires:  cmake(Qt6LinguistTools)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(lxqt2-build-tools)
BuildRequires:  pkgconfig(lxqt) >= 2.1.0
Recommends:     %{name}-lang = %{version}-%{release}

%description
The LXQt Notification daemon

%lang_package

%prep
%autosetup
sed -i '/Categories/s/\(LXQt\)/X-\1/' ./config/lxqt-config-notificationd.desktop.in

%build
%cmake_qt6
%{qt6_build}

%install
%{qt6_install}
%fdupes -s %{buildroot}%{_datadir}

%find_lang %{name} --with-qt --all-name

%files
%license LICENSE
%doc AUTHORS CHANGELOG README.md
%{_bindir}/%{name}
%{_bindir}/lxqt-config-notificationd
%{_datadir}/applications/lxqt-config-notificationd.desktop
%config %{_sysconfdir}/xdg/autostart/lxqt-notifications.desktop

%files lang -f %{name}.lang
%dir %{_datadir}/lxqt
%dir %{_datadir}/lxqt/translations
%dir %{_datadir}/lxqt/translations/lxqt-config-notificationd
%dir %{_datadir}/lxqt/translations/%{name}

%changelog
* Thu Apr 17 2025 Shawn Dunn <sfalken@opensuse.org>
- Update to version 2.2.0:
  * Workaround for text misalignment on decreasing the notification
    width
  * By default, show notifications on the leftmost/topmost screen
    under Wayland, as if it's the primary screen
  * Allowed zero duration in the config GUI, which means no
    auto-closing without an explicit timeout
  * Improved the texts of the section "Unattended Notifications" in
    the config GUI
- Removed Group: declarations, no longer used
* Mon Dec 23 2024 Андрей Алыпов <and.november@opensuse.org>
- Update to version 2.1.1:
  * Fixed transparent notifications with System theme on Wayland.
* Wed Nov  6 2024 Андрей Алыпов <and.november@opensuse.org>
- Update to version 2.1.0:
  * Pre-release changes (#403)
  * Weblate commits (#404)
  * Weblate commits (#401)
  * Workaround for translucency artifacts with Qt 6.8.0 on Wayland (#402)
  * Weblate commits (#399)
  * Updated *.ts files (including Luganda) (#400)
  * Weblate commits (#398)
  * Weblate commits (#397)
  * Fixed recent regression (#396)
  * Updated *.ts files (#395)
* Sat May 11 2024 Андрей Алыпов <and.november@opensuse.org>
- Update to 2.0.1:
  * Prevented a random crash on killing the process with Qt ≥ 6.7.
  * Ported to Qt6.
  * Added full Wayland support by using layer shell.
* Sun Nov  5 2023 Shawn Dunn <sfalken@opensuse.org>
- Update to 1.4.0:
  * Moved the size and margin settings to the Appearance page of
    config dialog.
  * Exit upon unsuccesful initialization.
  * Some code cleanup.
* Sat Apr 15 2023 Shawn Dunn <sfalken@opensuse.org>
- Update to 1.3.0:
  * Updated translations and bumped the version
* Sat Nov  5 2022 Shawn Dunn <sfalken@cloverleaf-linux.org>
- Update to 1.2.0:
  * Allow no focused widget inside notifications (useful under Wayland).
  * Don't show default actions if nameless (no empty button, no
    empty combo-box item).
* Fri Apr 29 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.1.0:
  * The configuration GUI is polished.
  * The notification icon is updated when global settings are changed.
* Mon Nov  8 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.0.0:
  * The do-not-disturb mode is added.
* Fri Apr 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 0.17.0:
  * The notification summary is always handled as plain-text.
  * Code cleanup.
* Wed Nov  4 2020 Michael Vetter <mvetter@suse.com>
- Update to 0.16.0:
  * Avoided container detachment.
  * Dropped deprecated QProcess method.
  * Added an option for showing notifications in the screen with
    the mouse pointer.
* Mon Apr 27 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Changed lxqt-notificationd.keyring to tsujan's key
* Sat Apr 25 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 0.15.0
  * Asynchronous calls are used to query server status information.
* Mon Jan 27 2020 Michael Vetter <mvetter@suse.com>
- bsc#1161365: Fix build
- Add buildrequire for glib
* Fri Mar  1 2019 mvetter@suse.com
- Update to 0.14.1:
  * Only translations was changed
* Thu Jan 31 2019 Michael Vetter <mvetter@suse.com>
- Update to 0.14.0:
  * Notification history implemented
  * Implementations fixed:
  - Fixed notification styles
  - Don't use automatic string conversions
  - Use QLatin1String where it is more efficient
  - Test app updated
  * Improved cmake scripting
  - Set cmake_minimum_required to 3.1.0
  - Removed locale compile definitons
  * Moved translations from lxqt-l10n back to lxqt-notificationd
  - Removed obsolete translation fuctionality
  - Added translation promo in README.md
  * Translation updates
- Move translation from lxqt-l10n into package
* Tue May 22 2018 mvetter@suse.com
- Update to 0.13.0:
  * Spanish translation update
  * Include QStyle and QStyleOption to fix compilation with Qt5.11
  * CMake: Prevent in-source builds
  * notificationlayout: Remove the "on top" hint
  * fix razor-qt -> lxqt and http -> https
  * Fix mentions of LXDE
  * Fix typo
  * Fix spanish translation
  * Update Simplified Chinese desktop entry
  * Update Traditional Chinese translation
  * Drop Qt foreach
  * cmake: Handle CMP0071
  * Change icon to preferences-desktop-notification
* Mon Oct 23 2017 mvetter@suse.com
- Update to 0.12.0:
  * Set patch version
  * Don't export github templates
  * Improvement for notification settings, see https://github.com/lxde/lxqt/issues/744#issuecomment-138601402
  * Updated Lithuanian language
  * Drops Qt5Core_VERSION_STRING
  * lxqt-config-notificationd: set Qt::AA_UseHighDpiPixmaps to true
  * Add a basic cli to lxqt-config-notificationd Add a basic cli to lxqt-notificationd
  * Added default CMAKE_BUILD_TYPE and LXQT_NOTIFICATION_PATCH_VERSION
  * Create lxqt-config-notificationd_pl_PL.desktop
  * Fixes a FTBFS in superbuild mode
  * Added merged autostart to CMakeLists.txt
  * Updated *_da.desktop files and removed *_da_DK.desktop files
  * Update desktop entries and Replace fr_FR by fr
  * Update Greek translation (el) Remove country variant from language code
  * CMake: Adds Runtime and Devel install COMPONENTs
  * Coding style changes
  * Updates the build system to use the Targets infrastructure
  * Drops hardcoded /etc/xdg paths
  * Updated german translation, replaced Qt4 by Qt in all xsession/translations
  * Updates translations infrastructure
  * Update the required minimum cmake version
  * remove dead template lines switch OnlyShowIn from Razor -> LXQt stringchanges LxQt -> LXQt
  * Support lxqt-session and add necessary xdg autostart desktop entry files.
  * Fix a typo: singals -> signals
  * Bump year
- Remove post and postun
* Thu Feb 23 2017 sfalken@opensuse.org
- Update to 0.11.1:
  * Updated da translation. Removed da_DK
  * Update and rename French .desktop file
  * Make CMakeList.txt more uniform.
  * Remove cpack (#53)
* Sat Sep 24 2016 mvetter@suse.com
- Update to 0.11.0:
  * Update and extend README.md
  * Add Catalan translation
  * build: Use external translations
  * ts-files removal (#50)
  * Clean up qDebugs/comments in notification.cpp
  * config: Use our specific icon for demo
  * Fix used licenses in AUTHORS, lxqt-notificationd is pure LGPL Bump year in AUTHORS
  * Italian translation update
  * Updated Russian translation Removed ru_RU files
  * notification: Default icon
  * notification: Fill background
  * update lxqt-config-notificationd_hu.ts
  * Update lxqt-config-notificationd_it.ts
* Sat Jul 30 2016 luke.nukem.jones@gmail.com
- Update summary and description to match the package.
* Fri Nov  6 2015 mvetter@suse.com
- Upstream release 0.10.0
- Removing patches:
  * fix_desktop_file.patch- Using sed in spec file now.
* Fri Feb 20 2015 sfalken@opensuse.org
- Changed %%build and %%install to use cmake macros
* Mon Feb  9 2015 sfalken@opensuse.org
- New upstream version 0.9.0
- Added -lang subpackage
- Added patch
  + fix_desktop_file.patch
* Sun Jan 25 2015 sfalken@opensuse.org
- Added conditionals to enable Fedora builds
* Sat Oct 25 2014 andrea@opensuse.org
- new upstream version 0.8.0
* Tue May 13 2014 andrea@opensuse.org
- removed unused buildrequires
* Tue May 13 2014 sfalken@opensuse.org
- Specfile cleanup
* Mon May 12 2014 sfalken@opensuse.org
- Removed fedora specfile, split into subproject
  Del:  lxqt-notificationd-Fedora_20.spec
* Sat May 10 2014 sfalken@opensuse.org
- ran spec-cleaner on openSUSE specfile
* Fri May  9 2014 sfalken@opensuse.org
- Added specfile for Fedora_20
  Add:  lxqt-notificationd-Fedora_20.spec
* Fri May  9 2014 sfalken@opensuse.org
- Added tarball for new stable release
  Add:  lxqt-notificationd-0.7.0.tar.xz
  Del:  _service
* Wed Apr  2 2014 sfalken@opensuse.org
- Removed direct cmake calls, in favour of %%cmake and %%cmake_install
* Wed Apr  2 2014 sfalken@opensuse.org
- Initial Source Upload
  Add: _service
  Add: lxqt-notificationd.spec
  Add: lxqt-notificationd.changes
